diff --git a/BACKLOG.md b/BACKLOG.md
index 63de508e718334a24f703555ee4578ef81c32c2d..61ed370ba7452cb5f644642953da72b1d1ecc011 100644
--- a/BACKLOG.md
+++ b/BACKLOG.md
@@ -106,8 +106,8 @@
 
 ### 0.0.15 Release
 * Issue #39 SQLalchemy instead of SQL: AllModelClasses.remove_all()
-* Issue #40 SQLalchemy instead of SQL: EuropeDataImportTable.get_date_rep()
-* Issue #41 SQLalchemy instead of SQL: EuropeDataImportTable.get_countries_of_continent()
+* Issue #40 SQLalchemy instead of SQL: EuropeDataImport.get_date_rep()
+* Issue #41 SQLalchemy instead of SQL: EuropeDataImport.get_countries_of_continent()
 * Issue #42 SQLalchemy instead of SQL: WhoGlobalDataImportTable.get_new_dates_as_array()
 * Issue #71 add python modules to requirements.txt for User Login, Authentication and Autorisation
 * Issue #72 add python modules to requirements.txt for Ajax and other JS Features
@@ -144,10 +144,10 @@
 * Issue #104 implement VaccinationsServiceUpdate.update_star_schema_incremental
 * Issue #105 implement VaccinationsServiceUpdate.update_star_schema_initial
 * Issue #106 add Tasks and URLs for starting Tasks to vaccination_views
-* Issue #107 SQLalchemy instead of SQL in: EuropeDataImportTable.get_countries_of_continent
-* Issue #108 change to ORM ClassHierarchy in: EuropeDataImportTable.get_countries_of_continent
-* Issue #109 SQLalchemy instead of SQL in: EuropeDataImportTable.get_date_rep
-* Issue #110 SQLalchemy instead of SQL in: EuropeDataImportTable.get_continent
+* Issue #107 SQLalchemy instead of SQL in: EuropeDataImport.get_countries_of_continent
+* Issue #108 change to ORM ClassHierarchy in: EuropeDataImport.get_countries_of_continent
+* Issue #109 SQLalchemy instead of SQL in: EuropeDataImport.get_date_rep
+* Issue #110 SQLalchemy instead of SQL in: EuropeDataImport.get_continent
 * Issue #111 refactor to new method scheme itroduced 07.02.2021
 * Issue #112 implement EuropeService.run_update_dimension_tables_only
 * Issue #113 implement EuropeService.run_update_fact_table_incremental_only
diff --git a/src/covid19/blueprints/europe/europe_service_import.py b/src/covid19/blueprints/europe/europe_service_import.py
index 85b8522423fecc5b9f7ca4d236dea51122abf7bb..2ef7b7f64d6c7a1a60415fca3d48685565b97d08 100644
--- a/src/covid19/blueprints/europe/europe_service_import.py
+++ b/src/covid19/blueprints/europe/europe_service_import.py
@@ -3,7 +3,7 @@ import csv
 import psycopg2
 
 from database import db, app
-from covid19.blueprints.europe.europe_model_import import EuropeDataImportTable
+from covid19.blueprints.europe.europe_model_import import EuropeDataImport
 from covid19.blueprints.europe.europe_service_config import EuropeServiceDownloadConfig
 
 
@@ -26,11 +26,11 @@ class EuropeServiceImport:
         app.logger.info("------------------------------------------------------------")
         k = 0
         try:
-            EuropeDataImportTable.remove_all()
+            EuropeDataImport.remove_all()
             with open(src_cvsfile_name, newline='') as csv_file:
                 file_reader = csv.DictReader(csv_file, delimiter=',', quotechar='"')
                 for row in file_reader:
-                    o = EuropeDataImportTable(
+                    o = EuropeDataImport(
                         date_rep=row['dateRep'],
                         year_week=row['year_week'],
                         cases_weekly=row['cases_weekly'],
diff --git a/src/covid19/blueprints/europe/europe_service_update.py b/src/covid19/blueprints/europe/europe_service_update.py
index 3ce239b4dd8581df7e07c3a8aafe6966d5e4361a..4e50968591d486e01ed979fdc4d1bc1b66dc3f77 100644
--- a/src/covid19/blueprints/europe/europe_service_update.py
+++ b/src/covid19/blueprints/europe/europe_service_update.py
@@ -1,6 +1,6 @@
 from database import db, app
 from covid19.blueprints.europe.europe_service_config import EuropeServiceDownloadConfig
-from covid19.blueprints.europe.europe_model_import import EuropeDataImportTable
+from covid19.blueprints.europe.europe_model_import import EuropeDataImport
 from covid19.blueprints.europe.europe_model import EuropeDateReported, EuropeContinent, EuropeCountry, EuropeData
 
 
@@ -18,7 +18,7 @@ class EuropeServiceUpdate:
     def __update_date_reported(self):
         app.logger.info(" __update_date_reported [begin]")
         app.logger.info("------------------------------------------------------------")
-        result_date_rep = EuropeDataImportTable.get_date_rep()
+        result_date_rep = EuropeDataImport.get_date_rep()
         k = 0
         for result_item in result_date_rep:
             k += 1
@@ -37,7 +37,7 @@ class EuropeServiceUpdate:
     def __update_continent(self):
         app.logger.info(" __update_continent [begin]")
         app.logger.info("------------------------------------------------------------")
-        result_continent = EuropeDataImportTable.get_continent()
+        result_continent = EuropeDataImport.get_continent()
         for result_item in result_continent:
             my_continent_exp = result_item['continent_exp']
             o = EuropeContinent(
@@ -55,7 +55,7 @@ class EuropeServiceUpdate:
         app.logger.info("------------------------------------------------------------")
         all_continents = EuropeContinent.get_all()
         for my_continent in all_continents:
-            result_countries_of_continent = EuropeDataImportTable.get_countries_of_continent(my_continent)
+            result_countries_of_continent = EuropeDataImport.get_countries_of_continent(my_continent)
             for c in result_countries_of_continent:
                 o = EuropeCountry(
                     countries_and_territories=c['countries_and_territories'],
@@ -73,7 +73,7 @@ class EuropeServiceUpdate:
     def __update_data_initial(self):
         app.logger.info(" __update_data_initial [begin]")
         app.logger.info("------------------------------------------------------------")
-        result_date_rep = EuropeDataImportTable.get_date_rep()
+        result_date_rep = EuropeDataImport.get_date_rep()
         i = 0
         for item_date_rep in result_date_rep:
             europe_date_reported = EuropeDateReported.find_by_date_reported(
@@ -82,7 +82,7 @@ class EuropeServiceUpdate:
             if europe_date_reported is None:
                 o = EuropeDateReported.create_new_object_factory(item_date_rep['date_rep'])
                 europe_date_reported = o
-            result_europe_data_import = EuropeDataImportTable.find_by_date_reported(europe_date_reported)
+            result_europe_data_import = EuropeDataImport.find_by_date_reported(europe_date_reported)
             for item_europe_data_import in result_europe_data_import:
                 my_a = item_europe_data_import.countries_and_territories
                 my_b = item_europe_data_import.geo_id
diff --git a/src/covid19/blueprints/europe/europe_views.py b/src/covid19/blueprints/europe/europe_views.py
index 000073849736b3f4464eea03b51a83a4bb96cb52..baa194d5feb77568dc6a2ac874461aa62e94d602 100644
--- a/src/covid19/blueprints/europe/europe_views.py
+++ b/src/covid19/blueprints/europe/europe_views.py
@@ -6,7 +6,7 @@ from database import app
 from covid19.services import europe_service
 from covid19.workers import celery
 
-from covid19.blueprints.europe.europe_model_import import EuropeDataImportTable
+from covid19.blueprints.europe.europe_model_import import EuropeDataImport
 from covid19.blueprints.europe.europe_model import EuropeDateReported, EuropeContinent, EuropeCountry, EuropeData
 from covid19.blueprints.common.common_model_transient import ApplicationPage
 
@@ -85,7 +85,7 @@ def europe_update_data_short():
 @app_europe.route('/imported')
 def url_europe_data_imported(page=1):
     page_info = ApplicationPage('Europe', "Last Import")
-    page_data = EuropeDataImportTable.get_all_as_page(page)
+    page_data = EuropeDataImport.get_all_as_page(page)
     return render_template(
         'europe/europe_imported.html',
         page_data=page_data,
diff --git a/src/covid19/blueprints/europe/europe_model_import.py b/src/covid19/blueprints/europe/europe_model_import.py
index 1e54b5a5506b122f8befcb945ec87fcd27d889df..69facf2bd010ba4d535f47acde369831e4313550 100644
--- a/src/covid19/blueprints/europe/europe_model_import.py
+++ b/src/covid19/blueprints/europe/europe_model_import.py
@@ -1,8 +1,8 @@
 from database import db, ITEMS_PER_PAGE
 
 
-class EuropeDataImportTable(db.Model):
-    __tablename__ = 'europe_data_import'
+class EuropeDataImport(db.Model):
+    __tablename__ = 'europe_import'
 
     id = db.Column(db.Integer, primary_key=True)
     date_rep = db.Column(db.String(255), nullable=False)
@@ -44,13 +44,13 @@ class EuropeDataImportTable(db.Model):
 
     @classmethod
     def get_date_rep(cls):
         # TODO: #109 SQLalchemy instead of SQL in: EuropeDataImportTable.get_date_rep
         sql = "select distinct date_rep, year_week from europe_data_import order by year_week desc"
         return db.session.execute(sql).fetchall()
 
     @classmethod
     def get_continent(cls):
         # TODO: #110 SQLalchemy instead of SQL in: EuropeDataImportTable.get_continent
         sql = "select distinct continent_exp from europe_data_import order by continent_exp asc"
         return db.session.execute(sql).fetchall()
 
@@ -59,8 +59,8 @@ class EuropeDataImportTable(db.Model):
         my_continent_exp = my_continent.region
         my_params = {}
         my_params['my_continent_param'] = my_continent_exp
         #TODO: #107 SQLalchemy instead of SQL in: EuropeDataImportTable.get_countries_of_continent
         #TODO: #108 BUG: change to ORM ClassHierarchy in: EuropeDataImportTable.get_countries_of_continent
         sql = """
         select distinct
             countries_and_territories,
@@ -69,7 +69,7 @@ class EuropeDataImportTable(db.Model):
             pop_data_2019,
             continent_exp
         from
-            europe_data_import
+            europe_import
         group by
             countries_and_territories,
             geo_id,
@@ -44,13 +44,13 @@ class EuropeDataImportTable(db.Model):
     @classmethod
     def get_date_rep(cls):
-        # TODO: #109 SQLalchemy instead of SQL in: EuropeDataImportTable.get_date_rep
+        # TODO: #109 SQLalchemy instead of SQL in: EuropeDataImport.get_date_rep
         sql = "select distinct date_rep, year_week from europe_data_import order by year_week desc"
         return db.session.execute(sql).fetchall()
@@ -44,13 +44,13 @@ class EuropeDataImportTable(db.Model):
     @classmethod
     def get_continent(cls):
-        # TODO: #110 SQLalchemy instead of SQL in: EuropeDataImportTable.get_continent
+        # TODO: #110 SQLalchemy instead of SQL in: EuropeDataImport.get_continent
         sql = "select distinct continent_exp from europe_data_import order by continent_exp asc"
         return db.session.execute(sql).fetchall()
@@ -59,8 +59,8 @@ class EuropeDataImportTable(db.Model):
         my_params = {}
         my_params['my_continent_param'] = my_continent_exp
-        #TODO: #107 SQLalchemy instead of SQL in: EuropeDataImportTable.get_countries_of_continent
-        #TODO: #108 BUG: change to ORM ClassHierarchy in: EuropeDataImportTable.get_countries_of_continent
+        #TODO: #107 SQLalchemy instead of SQL in: EuropeDataImport.get_countries_of_continent
+        #TODO: #108 BUG: change to ORM ClassHierarchy in: EuropeDataImport.get_countries_of_continent
         sql = """
         select distinct